package cat.binary.capturavideo;

import java.io.IOException;
import android.content.Context;
import android.hardware.Camera;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;

// Aquesta classe ens permet previsualitzar el contingut de la camera
// dins d'un Layout o rea
public class PrevisualitzacioCam extends SurfaceView implements SurfaceHolder.Callback 
{

	// Definir les variables locals de la classe
	private SurfaceHolder mTitular;
	private Camera mCamera;

	// Crear el constructor de la classe
	public PrevisualitzacioCam(Context context, Camera camera) 
	{
		super(context);
		mCamera = camera;
		mTitular = getHolder();
		mTitular.addCallback(this);
	}

	// Metode de creacio de la superficie on fer la previsualitzacio
	public void surfaceCreated(SurfaceHolder titular) 
	{
		try 
		{
			// Crear la superficie i iniciar la previsualitzacio
			if (mCamera == null) 
			{
				mCamera.setPreviewDisplay(titular);
				mCamera.startPreview();
			}
		} 
		catch (IOException ex) 
		{
			Log.d(VIEW_LOG_TAG, "Error de previsualitzacio : " + ex.getMessage());
		}
	}

	// Metode refrescar el contingut de la camera
	public void refrescarCamera(Camera camera) 
	{
		// Si no existeix la superficio on previsualitzar : sortir
		if (mTitular.getSurface() == null) 
		{
			return;
		}
		
		// Parar la previsualitzacio abans de fer canvis
		try 
		{
			mCamera.stopPreview();
		} 
		catch (Exception ex) 
		{
			// Si no es pot parar la camera es gener un error
		}
		
		// Definir la mida de previsualitzacio i crear un resize,
		// o una rotaci. Desprs dels canvis fer una previsualitzacio
		// ams la nova configuraci
		
		// Definir la camera
		setCamera(camera);
		
		try 
		{
			mCamera.setPreviewDisplay(mTitular);
			mCamera.startPreview();
		} 
		catch (Exception e) 
		{
			Log.d(VIEW_LOG_TAG, "Error al intentar fer el preview : " + e.getMessage());
		}
	}

	// Si es produeix un canvi de rotacio, s'ha de parar la previsualitzacio
	// i tornar-la iniciar amb la nova configuraci
	public void surfaceChanged(SurfaceHolder holder, int format, int w, int h) {
		refrescarCamera(mCamera);
	}

	// Metode per definir quina es la camera que estem treballan
	public void setCamera(Camera camera) 
	{
		mCamera = camera;
	}

	// Metode per destruir la camera al final del proces
	@Override
	public void surfaceDestroyed(SurfaceHolder holder) 
	{

	}

}
